@@ -2,10 +2,10 @@
 // SPDX-License-Identifier: Apache-2.0, MIT
 
 use cid::Cid;
-use fvm_ipld_blockstore::Blockstore;
-use fvm_ipld_encoding::RawBytes;
 use fvm_shared::actor::builtin::Type;
 use fvm_shared::address::Address;
+use fvm_shared::blockstore::Blockstore;
+use fvm_shared::encoding::RawBytes;
 use fvm_shared::error::ExitCode;
 use fvm_shared::{MethodNum, METHOD_CONSTRUCTOR};
 use num_derive::FromPrimitive;
@@ -58,15 +58,9 @@ impl Actor {
 
         let result = rt.send(arg.to, arg.method, arg.params, arg.value);
         if let Err(e) = result {
-            Ok(SendReturn {
-                return_value: RawBytes::default(),
-                code: e.exit_code(),
-            })
+            Ok(SendReturn { return_value: RawBytes::default(), code: e.exit_code() })
         } else {
-            Ok(SendReturn {
-                return_value: result.unwrap(),
-                code: ExitCode::OK,
-            })
+            Ok(SendReturn { return_value: result.unwrap(), code: ExitCode::Ok })
         }
     }
 
@@ -124,11 +118,7 @@ impl Actor {
     {
         rt.validate_immediate_caller_accept_any()?;
         // TODO Temporarily fine to use default as Undefined Cid, but may need to change in the future
-        let actor_cid = if arg.undef_cid {
-            Cid::default()
-        } else {
-            arg.cid
-        };
+        let actor_cid = if arg.undef_cid { Cid::default() } else { arg.cid };
 
         let actor_address = arg.actor_id;
 
@@ -174,7 +164,7 @@ impl Actor {
                 Ok(())
             }),
 
-            _ => Err(actor_error!(USR_ILLEGAL_ARGUMENT; "Invalid mutate state command given" )),
+            _ => Err(actor_error!(ErrIllegalArgument; "Invalid mutate state command given" )),
         }
     }
 
@@ -256,7 +246,7 @@ impl ActorCode for Actor {
                 Ok(RawBytes::serialize(inspect)?)
             }
 
-            None => Err(actor_error!(SYS_INVALID_METHOD; "Invalid method")),
+            None => Err(actor_error!(SysErrInvalidMethod; "Invalid method")),
         }
     }
 }
