@@ -1,7 +1,7 @@
 // Copyright 2019-2022 ChainSafe Systems
 // SPDX-License-Identifier: Apache-2.0, MIT
 
-use fvm_ipld_encoding::Cbor;
+use fvm_shared::encoding::Cbor;
 use serde::de::{self, Deserializer};
 use serde::ser::{self, Serializer};
 use serde::{Deserialize, Serialize};
@@ -13,9 +13,7 @@ impl Serialize for UnmarshallableCBOR {
     where
         S: Serializer,
     {
-        Err(ser::Error::custom(
-            "Automatic fail when serializing UnmarshallableCBOR",
-        ))
+        Err(ser::Error::custom("Automatic fail when serializing UnmarshallableCBOR"))
     }
 }
 
@@ -24,9 +22,7 @@ impl<'de> Deserialize<'de> for UnmarshallableCBOR {
     where
         D: Deserializer<'de>,
     {
-        Err(de::Error::custom(
-            "Automatic fail when deserializing UnmarshallableCBOR",
-        ))
+        Err(de::Error::custom("Automatic fail when deserializing UnmarshallableCBOR"))
     }
 }
 
@@ -34,7 +30,7 @@ impl Cbor for UnmarshallableCBOR {}
 
 #[cfg(test)]
 mod tests {
-    use fvm_ipld_encoding::RawBytes;
+    use fvm_shared::encoding::RawBytes;
 
     use super::*;
 
